#!/usr/bin/env python

HOST = "http://www.shellstreamer.com/"
BASH_PROMPT = "[SHSTREAM]"
